import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple','lemon'])
	.range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range([50, 30]);

export const fruitBowl = (selection, props ) => {
  const { fruits, height, selectFruit, selectedFruit } = props;
  
  const bowl = selection.selectAll('rect')
  	.data([null])
   	.enter().append('rect')
      .attr('y', 100)
      .attr('width', 650)
      .attr('height', 300)
      .attr('rx', 150);
  
  const groups = selection.selectAll('g').data(fruits);
  const groupsEnter = groups.enter().append('g');
  groupsEnter.merge(groups)
  	.attr('transform', (d, i) => `translate(${i * 120 + 80}, ${height/2})`)
  groups.exit().remove();
  
  groupsEnter
    .append('circle')
    .merge( groups.select('circle'))
  		.on('mouseover', d => selectFruit(d.id))
  		.on('mouseout', () => selectFruit(null))
  		.attr('stroke-width', 5)
    	.attr('stroke', d => d.id === selectedFruit ? 'black' : 'none')
  		.transition().duration(1000)
      .attr('fill', d => colorScale(d.type))
      .attr('r', d => radiusScale(d.type))
  
	groupsEnter.append('text')
    .merge(groups.select('text'))
  		.text(d => d.type)
  		.attr('y', 80);
}